@@ -1,5 +1,5 @@
 package Photonic::LE::NR2::SHP;
-$Photonic::LE::NR2::SHP::VERSION = '0.014';
+$Photonic::LE::NR2::SHP::VERSION = '0.015';
 
 =encoding UTF-8
 
@@ -9,14 +9,14 @@ Photonic::LE::NR2::SHP
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 COPYRIGHT NOTICE
 
 Photonic - A perl package for calculations on photonics and
 metamaterials.
 
-Copyright (C) 1916 by W. Luis Mochán
+Copyright (C) 2016 by W. Luis Mochán
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -107,14 +107,9 @@ use namespace::autoclean;
 use PDL::Lite;
 use PDL::NiceSlice;
 use PDL::Complex;
-use PDL::FFTW3;
-use PDL::Constants qw(PI);
-use Photonic::Utils qw(RtoG HProd linearCombine);
-use Photonic::ExtraUtils qw(cgtsl);
 use Moose;
 use MooseX::StrictConstructor;
 
-
 has 'nrf'=>(is=>'ro', isa=>'Photonic::LE::NR2::Field', required=>1,
          documentation=>'Haydock field calculator');
 has 'densityA'=>(is=>'ro', isa=>'Num', required=>1,
