@@ -1,5 +1,5 @@
 package Photonic::WE::S::EpsilonTensor;
-$Photonic::WE::S::EpsilonTensor::VERSION = '0.014';
+$Photonic::WE::S::EpsilonTensor::VERSION = '0.015';
 
 =encoding UTF-8
 
@@ -9,14 +9,14 @@ Photonic::WE::S::EpsilonTensor
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 COPYRIGHT NOTICE
 
 Photonic - A perl package for calculations on photonics and
 metamaterials.
 
-Copyright (C) 1916 by W. Luis Mochán
+Copyright (C) 2016 by W. Luis Mochán
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -120,7 +120,7 @@ sub _build_epsilonTensor {
     my $k=$self->metric->wavevector;
     if($q->isa('PDL::Complex') || $k->isa('PDL::Complex')){
 	#Make both complex
-	map {$_=r2C($_) unless $_->isa('PDL::Complex')} $q, $k;
+	$_ = $_->isa('PDL::Complex') ? $_ : r2C($_) for $q, $k;
 	my $k2=($k*$k)->sumover; #inner
 	my $kk=$k->(:,:,*1)*$k->(:,*1,:); #outer
 	my $id=identity($k);
